==> art-3.6.tar.gz: art-3.6/art/test2.py <==
# -*- coding: utf-8 -*-
'''
>>> import os
>>> import random
>>> from art import *
>>> from art.art_param import TEST_FILTERED_FONTS
>>> for i in sorted(TEST_FILTERED_FONTS):
...     print(i+":")
...     tprint("test",font=i)
antrophobia:
тєѕт
<BLANKLINE>
currency:
₮Ɇ₴₮
<BLANKLINE>
dirty:
ẗệṩẗ
<BLANKLINE>
fancy1:
тεsт
<BLANKLINE>
fancy10:
ɬɛʂɬ
<BLANKLINE>
fancy11:
тeѕт
<BLANKLINE>
fancy12:
tєѕt
<BLANKLINE>
fancy13:
tєรt
<BLANKLINE>
fancy14:
ᏆᎬsᏆ
<BLANKLINE>
fancy15:
✞ƎƧ✞
<BLANKLINE>
fancy16:
ΓΞSΓ
<BLANKLINE>
fancy17:
ᏆɛֆᏆ
<BLANKLINE>
fancy18:
ԵҽՏԵ
<BLANKLINE>
fancy19:
꓄ꍟꌗ꓄
<BLANKLINE>
fancy2:
ㄒ乇丂ㄒ
<BLANKLINE>
fancy20:
ᵀᴱˢᵀ
<BLANKLINE>
fancy21:
тeѕт
<BLANKLINE>
fancy22:
ŤƐらŤ
<BLANKLINE>
fancy23:
ƬЄƧƬ
<BLANKLINE>
fancy24:
ϮꂅᏕϮ
<BLANKLINE>
fancy25:
ｲ乇丂ｲ
<BLANKLINE>
fancy26:
†εš†
<BLANKLINE>
fancy27:
tēŞt
<BLANKLINE>
fancy3:
ŤĔŚŤ
<BLANKLINE>
fancy4:
ᏆᎬsᏆ
<BLANKLINE>
fancy5:
ᏖᏋᏕᏖ
<BLANKLINE>
fancy6:
ƭεรƭ
<BLANKLINE>
fancy7:
丅ᗴᔕ丅
<BLANKLINE>
fancy8:
tєรt
<BLANKLINE>
fancy9:
тeѕт
<BLANKLINE>
flip:
ϝԍƨϝ
<BLANKLINE>
full_width:
ｔｅｓｔ
<BLANKLINE>
knight:
ṮḕṠṮ
<BLANKLINE>
magical:
ᏆᎬsᏆ
<BLANKLINE>
mirror:
ɈƨǝɈ
<BLANKLINE>
mirror_flip:
ʇsǝʇ
<BLANKLINE>
paranormal:
tєѕt
<BLANKLINE>
smallcaps2:
ᴛᴇsᴛ
<BLANKLINE>
sorcerer:
ᏆɛֆᏆ
<BLANKLINE>
special:
TEᔕT
<BLANKLINE>
subscript:
ₜₑₛₜ
<BLANKLINE>
superscript:
ᵗᵉˢᵗ
<BLANKLINE>
thin2:
ｔｅｓｔ
<BLANKLINE>
tiny:
ᴛᴇᴤᴛ
<BLANKLINE>
white_bubble:
ⓣⓔⓢⓣ
<BLANKLINE>
>>> random.seed(24)
>>> Art = text2art("test","rnd-na")
>>> random.seed(45)
>>> Art2 = text2art("test","rnd-na")
>>> Art == Art2
False
>>> Data = tsave("test@34",font="antrophobia",filename="antrophobia.txt")
Saved!
Filename: antrophobia.txt
>>> Data = tsave("test@34",font="magical",filename="magical.txt")
Saved!
Filename: magical.txt
>>> os.remove("antrophobia.txt")
>>> os.remove("magical.txt")

'''

==> art-4.1.tar.gz: art-4.1/art/test2.py <==
# -*- coding: utf-8 -*-
'''
>>> import os
>>> import random
>>> from art import *
>>> from art.art_param import TEST_FILTERED_FONTS
>>> for i in sorted(TEST_FILTERED_FONTS):
...     print(i+":")
...     tprint("test",font=i)
antrophobia:
тєѕт
<BLANKLINE>
black_bubble:
🅣🅔🅢🅣
<BLANKLINE>
black_square:
🆃🅴🆂🆃
<BLANKLINE>
contouring1:
ⓣⓔⓢⓣ
<BLANKLINE>
contouring2:
⒯⒠⒮⒯
<BLANKLINE>
contouring3:
[̲̅t][̲̅e][̲̅s][̲̅t]
<BLANKLINE>
contouring4:
(̲̅t)(̲̅e)(̲̅s)(̲̅t)
<BLANKLINE>
currency:
₮Ɇ₴₮
<BLANKLINE>
dirty:
ẗệṩẗ
<BLANKLINE>
fancy1:
тεsт
<BLANKLINE>
fancy10:
ɬɛʂɬ
<BLANKLINE>
fancy11:
ՇєรՇ
<BLANKLINE>
fancy12:
tєѕt
<BLANKLINE>
fancy13:
tєรt
<BLANKLINE>
fancy14:
ȶɛֆȶ
<BLANKLINE>
fancy15:
✞ƎƧ✞
<BLANKLINE>
fancy16:
ΓΞSΓ
<BLANKLINE>
fancy17:
ᏆɛֆᏆ
<BLANKLINE>
fancy18:
ԵҽՏԵ
<BLANKLINE>
fancy19:
꓄ꍟꌗ꓄
<BLANKLINE>
fancy2:
ㄒ乇丂ㄒ
<BLANKLINE>
fancy20:
ᵀᴱˢᵀ
<BLANKLINE>
fancy21:
тeѕт
<BLANKLINE>
fancy22:
ŤƐらŤ
<BLANKLINE>
fancy23:
ƬЄƧƬ
<BLANKLINE>
fancy24:
ϮꂅᏕϮ
<BLANKLINE>
fancy25:
ｲ乇丂ｲ
<BLANKLINE>
fancy26:
†εš†
<BLANKLINE>
fancy27:
tēŞt
<BLANKLINE>
fancy28:
ƬΣƧƬ
<BLANKLINE>
fancy29:
†ê§†
<BLANKLINE>
fancy3:
ŤĔŚŤ
<BLANKLINE>
fancy30:
ᖶᘿSᖶ
<BLANKLINE>
fancy31:
ནპჰན
<BLANKLINE>
fancy32:
꓄ꏂꑄ꓄
<BLANKLINE>
fancy33:
꓅ꍟꌚ꓅
<BLANKLINE>
fancy34:
ꋖꈼꌚꋖ
<BLANKLINE>
fancy35:
੮૯ς੮
<BLANKLINE>
fancy36:
ԵȝՏԵ
<BLANKLINE>
fancy37:
ꋖꏹꌚꋖ
<BLANKLINE>
fancy38:
ꋖꑀꈜꋖ
<BLANKLINE>
fancy39:
ፕቿነፕ
<BLANKLINE>
fancy4:
ᏆᎬsᏆ
<BLANKLINE>
fancy40:
꓅ꑾꇘ꓅
<BLANKLINE>
fancy41:
ț£§ț
<BLANKLINE>
fancy42:
ţ€$ţ
<BLANKLINE>
fancy43:
ᖶᙍSᖶ
<BLANKLINE>
fancy44:
тεƨт
<BLANKLINE>
fancy45:
тešт
<BLANKLINE>
fancy46:
էεʂէ
<BLANKLINE>
fancy47:
†ε$†
<BLANKLINE>
fancy48:
էεรէ
<BLANKLINE>
fancy49:
τεЅτ
<BLANKLINE>
fancy5:
ᏖᏋᏕᏖ
<BLANKLINE>
fancy50:
ҭἔṩҭ
<BLANKLINE>
fancy51:
7357
<BLANKLINE>
fancy52:
τEŠτ
<BLANKLINE>
fancy53:
ƮęsƮ
<BLANKLINE>
fancy54:
⊥ÈS⊥
<BLANKLINE>
fancy55:
t€$t
<BLANKLINE>
fancy56:
𝐭𝐞𝐬𝐭
<BLANKLINE>
fancy57:
𝚝𝚎𝚜𝚝
<BLANKLINE>
fancy58:
𝖙𝖊𝖘𝖙
<BLANKLINE>
fancy59:
𝕥𝕖𝕤𝕥
<BLANKLINE>
fancy6:
ƭεรƭ
<BLANKLINE>
fancy60:
𝘁𝗲𝘀𝘁
<BLANKLINE>
fancy61:
𝑡𝑒𝑠𝑡
<BLANKLINE>
fancy62:
𝘵𝘦𝘴𝘵
<BLANKLINE>
fancy63:
𝒕𝒆𝒔𝒕
<BLANKLINE>
fancy64:
𝙩𝙚𝙨𝙩
<BLANKLINE>
fancy65:
𝓉𝑒𝓈𝓉
<BLANKLINE>
fancy66:
𝓽𝒆𝓼𝓽
<BLANKLINE>
fancy67:
ｔｅｓｔ
<BLANKLINE>
fancy68:
𝔱𝔢𝔰𝔱
<BLANKLINE>
fancy69:
ᵗᵉᶳᵗ
<BLANKLINE>
fancy7:
丅ᗴᔕ丅
<BLANKLINE>
fancy70:
тeѕт
<BLANKLINE>
fancy71:
тєѕт
<BLANKLINE>
fancy72:
тєѕт
<BLANKLINE>
fancy73:
ŧêšŧ
<BLANKLINE>
fancy74:
ŧεşŧ
<BLANKLINE>
fancy75:
ｲ乇ㄎｲ
<BLANKLINE>
fancy76:
էҽʂէ
<BLANKLINE>
fancy77:
ƚҽʂƚ
<BLANKLINE>
fancy78:
tєรt
<BLANKLINE>
fancy79:
†εš†
<BLANKLINE>
fancy8:
tєรt
<BLANKLINE>
fancy80:
ƭєƨƭ
<BLANKLINE>
fancy81:
ƚЄ$ƚ
<BLANKLINE>
fancy82:
Ŧ£ŞŦ
<BLANKLINE>
fancy83:
τεȘτ
<BLANKLINE>
fancy84:
tΞst
<BLANKLINE>
fancy85:
ťĕʂť
<BLANKLINE>
fancy86:
ᴛᴇsᴛ
<BLANKLINE>
fancy9:
тeѕт
<BLANKLINE>
flip:
ϝԍƨϝ
<BLANKLINE>
full_width:
ｔｅｓｔ
<BLANKLINE>
knight:
ṮḕṠṮ
<BLANKLINE>
love1:
ƬƐSƬ
<BLANKLINE>
love2:
тєsт
<BLANKLINE>
mirror:
ɈƨǝɈ
<BLANKLINE>
mirror_flip:
ʇsǝʇ
<BLANKLINE>
paranormal:
tєst
<BLANKLINE>
smallcaps2:
ᴛᴇsᴛ
<BLANKLINE>
special:
TEᔕT
<BLANKLINE>
subscript:
ₜₑₛₜ
<BLANKLINE>
superscript:
ᵗᵉˢᵗ
<BLANKLINE>
symbols:
☂€ⓢ☂
<BLANKLINE>
thin2:
ｔｅｓｔ
<BLANKLINE>
tiny:
ᴛᴇᴤᴛ
<BLANKLINE>
white_bubble:
ⓣⓔⓢⓣ
<BLANKLINE>
white_square:
🅃🄴🅂🅃
<BLANKLINE>
>>> random.seed(24)
>>> Art = text2art("test","rnd-na")
>>> random.seed(45)
>>> Art2 = text2art("test","rnd-na")
>>> Art == Art2
False
>>> random.seed(24)
>>> Art = text2art("test","mix")
>>> random.seed(45)
>>> Art2 = text2art("test","mix")
>>> Art == Art2
False
>>> tprint("test","fancy1")
тεsт
<BLANKLINE>
>>> aprint("UnicodeEncodeError")
[Warning] 'UnicodeEncodeError' is not printable in this environment.
>>> tprint("test","UnicodeEncodeError")
[Warning] 'UnicodeEncodeError' is not printable in this environment.
>>> Data = tsave("test@34",font="antrophobia",filename="antrophobia.txt")
Saved!
Filename: antrophobia.txt
>>> Data = tsave("test@34",font="fancy37",filename="fancy37.txt")
Saved!
Filename: fancy37.txt
>>> os.remove("antrophobia.txt")
>>> os.remove("fancy37.txt")

'''
